@@ -18,7 +18,7 @@ function startUpload()
 {
     var errorMessage;
 
-    // ID  1 ʾˤ
+    // ID is more than 1.
     uploadID    = Math.floor(Math.random()*(Math.pow(2, 32)-1)) + 1;
     startTime   = getTime();
     progressInfo= document.getElementById('progress_info');
@@ -56,7 +56,7 @@ function startUpload()
 
 function startUpdateProgress()
 {
-    // ɽ 1 ˹롥
+    // reload every 1 sec.
     updateTimer = setInterval('updateProgress()', 1000);
     checkTimer = setInterval('checkResponse()', 2000);
 }
@@ -87,7 +87,7 @@ function updateProgress()
     progress = getProgress(uploaderURL + '/progress_data/' + uploadID);
 
     if (progress == null) {
-        if (++failCount > 5) {
+        if (++failCount > 10) {
             clearTimer();
         }
         setProgresssInfo('Server Busy.');
@@ -151,7 +151,7 @@ function getTime()
 function getProgressMessage(progress)
 {
     if (progress.totalSize == 0) {
-        return progress.readSize + ' / åץɥ';
+        return progress.readSize + ' / Unkown size';
     } else {
         return progress.readSize + ' / ' + progress.totalSize +
             ' (' + progress.getPercent() + '%) @ ' + progress.getSpeed() +
@@ -177,7 +177,7 @@ function getProgress(url)
         }, 3000);
 
         request.open('POST', url, false);
-        request.send(null);
+        request.send("GET progress");
         clearTimeout(timer);
 
         if ((request.status != 200) ||
@@ -287,5 +287,4 @@ function Progress(stat, totalSize, readSize)
 
 // Local Variables:
 // mode: javascript-generic
-// coding: euc-japan-unix
 // End:
