@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: ApacheRequestReader.cpp 2162 2006-12-03 14:36:10Z svn $
+ * $Id: ApacheRequestReader.cpp 2193 2006-12-09 01:26:55Z svn $
  *****************************************************************************/
 
 #include "ApacheRequestReader.h"
@@ -36,12 +36,12 @@
 #include "Macro.h"
 #include "SourceInfo.h"
 
-SOURCE_INFO_ADD("$Id: ApacheRequestReader.cpp 2162 2006-12-03 14:36:10Z svn $");
+SOURCE_INFO_ADD("$Id: ApacheRequestReader.cpp 2193 2006-12-09 01:26:55Z svn $");
 
 /******************************************************************************
  * public メソッド
  *****************************************************************************/
-ApacheRequestReader::ApacheRequestReader(progress_t *progress,
+ApacheRequestReader::ApacheRequestReader(post_progress_t *progress,
                                          request_rec *request)
     : RequestReader(progress),
       request_(request),
