@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: TemplateExecutor.cpp 2368 2007-01-13 09:48:03Z svn $
+ * $Id: TemplateExecutor.cpp 2388 2007-03-10 11:34:50Z svn $
  *****************************************************************************/
 
 #ifndef TEMPLATE_INSTANTIATION
@@ -41,7 +41,7 @@
 using namespace std;
 
 #ifndef TEMPLATE_INSTANTIATION
-SOURCE_INFO_ADD("$Id: TemplateExecutor.cpp 2368 2007-01-13 09:48:03Z svn $");
+SOURCE_INFO_ADD("$Id: TemplateExecutor.cpp 2388 2007-03-10 11:34:50Z svn $");
 #endif
 
 #ifdef DEBUG_TemplateExecutor
@@ -757,10 +757,10 @@ void run_all(apr_pool_t *pool, int argc, const char * const *argv)
         dump_level = 0;
     }
 
-    if (!is_exist(pool, data_dir_path)) {
+    if (!File::is_exist(pool, data_dir_path)) {
         THROW(MESSAGE_DATA_DIR_NOT_FOUND);
     }
-    if (!is_exist(pool, tmpl_file_path)) {
+    if (!File::is_exist(pool, tmpl_file_path)) {
         THROW(MESSAGE_TMPL_FILE_NOT_FOUND);
     }
 
