@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: uploader_handler.cpp 2394 2007-03-25 10:44:25Z svn $
+ * $Id: uploader_handler.cpp 2407 2007-04-28 17:38:05Z svn $
  *****************************************************************************/
 
 #ifndef TEMPLATE_INSTANTIATION
@@ -56,7 +56,7 @@
 #include "SourceInfo.h"
 
 #ifndef TEMPLATE_INSTANTIATION
-SOURCE_INFO_ADD("$Id: uploader_handler.cpp 2394 2007-03-25 10:44:25Z svn $");
+SOURCE_INFO_ADD("$Id: uploader_handler.cpp 2407 2007-04-28 17:38:05Z svn $");
 #endif
 
 #define IS_REQUEST_COMMAND(arg, command)                        \
@@ -734,9 +734,13 @@ static int download(typename Response::Handle *r, UploaderConfig *config,
                                      NUMNAME, uitem->get_index(),
                                      uitem->get_file_ext());
 #else
+#ifdef CONV_CHAR_CODE
             file_name = CharCodeConverter::convert
                 (r->pool, uitem->get_file_name(),
                  CharCodeConverter::DEFAULT_CODE, dispos_encoding);
+#else
+            file_name = uitem->get_file_name();
+#endif
 #endif
 
             // 表示モード or ダウンロードモード
